<?php
/**
 * @file
 * sc_example_layout.rules_defaults.inc
 */

/**
 * Implements hook_default_rules_configuration().
 */
function sc_example_layout_default_rules_configuration() {
  $items = array();
  $items['rules_clear_cache_resource_collections'] = entity_import('rules_config', '{ "rules_clear_cache_resource_collections" : {
      "LABEL" : "Clear cache: resource collections",
      "PLUGIN" : "rule set",
      "TAGS" : [ "Skill Compass caching" ],
      "REQUIRES" : [ "rules", "cache_actions" ],
      "USES VARIABLES" : { "resource" : { "label" : "Updated resource", "type" : "node" } },
      "RULES" : [
        { "RULE" : {
            "PROVIDE" : { "entity_fetched" : { "collections" : "Collections to clear" } },
            "DO" : [
              { "entity_query" : {
                  "USING" : {
                    "type" : "node",
                    "property" : "sc_resourcecollection_resources",
                    "value" : [ "resource" ]
                  },
                  "PROVIDE" : { "entity_fetched" : { "collections" : "Collections to clear" } }
                }
              },
              { "LOOP" : {
                  "USING" : { "list" : [ "collections" ] },
                  "ITEM" : { "collection" : "Collection" },
                  "DO" : [
                    { "cache_actions_action_clear_cache_cid" : {
                        "bin" : "cache",
                        "cid" : "resource_collection:[collection:nid]:[resource:nid]",
                        "wildcard" : 1
                      }
                    },
                    { "cache_actions_action_clear_cache_cid" : {
                        "bin" : "cache",
                        "cid" : "resource_collection:adm:[collection:nid]:[resource:nid]",
                        "wildcard" : 1
                      }
                    }
                  ]
                }
              }
            ],
            "LABEL" : "Clear related collections"
          }
        },
        { "RULE" : {
            "IF" : [
              { "node_is_of_type" : {
                  "node" : [ "resource" ],
                  "type" : { "value" : { "sc_resource_collection" : "sc_resource_collection" } }
                }
              }
            ],
            "DO" : [
              { "cache_actions_action_clear_cache_cid" : {
                  "bin" : "cache",
                  "cid" : "resource_collection:[resource:nid]",
                  "wildcard" : 1
                }
              },
              { "cache_actions_action_clear_cache_cid" : {
                  "bin" : "cache",
                  "cid" : "resource_collection:adm:[resource:nid]",
                  "wildcard" : 1
                }
              }
            ],
            "LABEL" : "Clear this collection"
          }
        }
      ]
    }
  }');
  $items['rules_sc_cache_account'] = entity_import('rules_config', '{ "rules_sc_cache_account" : {
      "LABEL" : "Clear cache: account page",
      "PLUGIN" : "rule set",
      "TAGS" : [ "Skill Compass caching" ],
      "REQUIRES" : [ "rules", "cache_actions" ],
      "USES VARIABLES" : {
        "account" : { "label" : "Account page to clear", "type" : "user" },
        "user" : { "label" : "Account to clear cache for", "type" : "user" }
      },
      "RULES" : [
        { "RULE" : {
            "IF" : [ { "data_is_empty" : { "data" : [ "user" ] } } ],
            "DO" : [
              { "cache_actions_action_clear_cache_cid" : { "bin" : "cache", "cid" : "account:[account:uid]", "wildcard" : 1 } },
              { "cache_actions_action_clear_cache_cid" : { "bin" : "cache", "cid" : "account:adm:[account:uid]", "wildcard" : 1 } }
            ],
            "LABEL" : "Clear for all"
          }
        },
        { "RULE" : {
            "IF" : [ { "NOT data_is_empty" : { "data" : [ "user" ] } } ],
            "DO" : [
              { "cache_actions_action_clear_cache_cid" : {
                  "bin" : "cache",
                  "cid" : "account:[account:uid]:[user:uid]",
                  "wildcard" : 0
                }
              },
              { "cache_actions_action_clear_cache_cid" : {
                  "bin" : "cache",
                  "cid" : "account:adm:[account:uid]:[user:uid]",
                  "wildcard" : 0
                }
              }
            ],
            "LABEL" : "Clear for specific user"
          }
        }
      ]
    }
  }');
  $items['rules_sc_cache_account_save'] = entity_import('rules_config', '{ "rules_sc_cache_account_save" : {
      "LABEL" : "Skill Compass: Clear cache on account save",
      "PLUGIN" : "reaction rule",
      "TAGS" : [ "Skill Compass caching" ],
      "REQUIRES" : [ "rules" ],
      "ON" : [ "user_update" ],
      "DO" : [
        { "component_rules_sc_cache_account" : { "account" : [ "account" ], "user" : "0" } }
      ]
    }
  }');
  $items['rules_sc_cache_resource'] = entity_import('rules_config', '{ "rules_sc_cache_resource" : {
      "LABEL" : "Clear cache: resource page",
      "PLUGIN" : "rule set",
      "TAGS" : [ "Skill Compass caching" ],
      "REQUIRES" : [ "rules", "cache_actions" ],
      "USES VARIABLES" : {
        "resource" : { "label" : "External resource", "type" : "node" },
        "account" : { "label" : "Account to clear cache for", "type" : "user" }
      },
      "RULES" : [
        { "RULE" : {
            "IF" : [ { "data_is_empty" : { "data" : [ "account" ] } } ],
            "DO" : [
              { "cache_actions_action_clear_cache_cid" : {
                  "bin" : "cache",
                  "cid" : "resource_external:[resource:nid]",
                  "wildcard" : 1
                }
              },
              { "cache_actions_action_clear_cache_cid" : {
                  "bin" : "cache",
                  "cid" : "resource_external:adm:[resource:nid]",
                  "wildcard" : 1
                }
              }
            ],
            "LABEL" : "Clear for all"
          }
        },
        { "RULE" : {
            "IF" : [
              { "NOT data_is_empty" : { "data" : [ "account" ] } },
              { "entity_has_field" : { "entity" : [ "resource" ], "field" : "sc_resource_topics" } }
            ],
            "DO" : [
              { "LOOP" : {
                  "USING" : { "list" : [ "resource:sc-resource-topics" ] },
                  "ITEM" : { "topic" : "Topic" },
                  "DO" : [
                    { "cache_actions_action_clear_cache_cid" : {
                        "bin" : "cache",
                        "cid" : "resource_external:[resource:nid]:[account:uid]:[topic:nid]",
                        "wildcard" : 0
                      }
                    },
                    { "cache_actions_action_clear_cache_cid" : {
                        "bin" : "cache",
                        "cid" : "resource_external:adm:[resource:nid]:[account:uid]:[topic:nid]",
                        "wildcard" : 0
                      }
                    }
                  ]
                }
              }
            ],
            "LABEL" : "Clear for specific user"
          }
        }
      ]
    }
  }');
  $items['rules_sc_cache_resource_comment'] = entity_import('rules_config', '{ "rules_sc_cache_resource_comment" : {
      "LABEL" : "Skill Compass: Clear cache on resource comment",
      "PLUGIN" : "reaction rule",
      "TAGS" : [ "Skill Compass caching" ],
      "REQUIRES" : [ "rules", "comment" ],
      "ON" : [ "comment_presave" ],
      "IF" : [
        { "entity_has_field" : { "entity" : [ "comment:node" ], "field" : "sc_resource_topics" } }
      ],
      "DO" : [
        { "component_rules_sc_cache_resource" : { "resource" : [ "comment:node" ], "account" : "0" } }
      ]
    }
  }');
  $items['rules_sc_cache_resource_list'] = entity_import('rules_config', '{ "rules_sc_cache_resource_list" : {
      "LABEL" : "Clear cache: resource list",
      "PLUGIN" : "rule set",
      "TAGS" : [ "Skill Compass caching" ],
      "REQUIRES" : [ "cache_actions" ],
      "RULES" : [
        { "RULE" : {
            "DO" : [
              { "cache_actions_action_clear_cache_cid" : { "bin" : "cache", "cid" : "resource_list", "wildcard" : 1 } }
            ],
            "LABEL" : "Clear for all"
          }
        }
      ]
    }
  }');
  $items['rules_sc_cache_resource_save'] = entity_import('rules_config', '{ "rules_sc_cache_resource_save" : {
      "LABEL" : "Skill Compass: Clear cache on resource save",
      "PLUGIN" : "reaction rule",
      "TAGS" : [ "Skill Compass caching" ],
      "REQUIRES" : [ "rules" ],
      "ON" : [ "node_presave" ],
      "IF" : [
        { "entity_has_field" : { "entity" : [ "node" ], "field" : "sc_resource_topics" } }
      ],
      "DO" : [
        { "component_rules_sc_cache_resource" : { "resource" : [ "node" ], "account" : "0" } },
        { "LOOP" : {
            "USING" : { "list" : [ "node:sc-resource-topics" ] },
            "ITEM" : { "topic" : "Topic" },
            "DO" : [
              { "component_rules_sc_cache_topic" : { "topic" : [ "topic" ], "account" : "0" } }
            ]
          }
        },
        { "component_rules_sc_cache_resource_list" : [] },
        { "component_rules_clear_cache_resource_collections" : { "resource" : [ "node" ] } }
      ]
    }
  }');
  $items['rules_sc_cache_resource_vote'] = entity_import('rules_config', '{ "rules_sc_cache_resource_vote" : {
      "LABEL" : "Skill Compass: Clear cache on resource vote",
      "PLUGIN" : "reaction rule",
      "TAGS" : [ "Skill Compass caching" ],
      "REQUIRES" : [ "rules", "voting_rules" ],
      "ON" : [ "voting_rules_insert_node" ],
      "IF" : [
        { "entity_has_field" : { "entity" : [ "node" ], "field" : "sc_resource_topics" } }
      ],
      "DO" : [
        { "component_rules_sc_cache_resource" : { "resource" : [ "node" ], "account" : "0" } },
        { "LOOP" : {
            "USING" : { "list" : [ "node:sc-resource-topics" ] },
            "ITEM" : { "topic" : "Topic" },
            "DO" : [
              { "component_rules_sc_cache_topic" : { "topic" : [ "topic" ], "account" : "0" } }
            ]
          }
        },
        { "component_rules_sc_cache_resource_list" : [] },
        { "component_rules_clear_cache_resource_collections" : { "resource" : [ "node" ] } }
      ]
    }
  }');
  $items['rules_sc_cache_topic'] = entity_import('rules_config', '{ "rules_sc_cache_topic" : {
      "LABEL" : "Clear cache: topic page",
      "PLUGIN" : "rule set",
      "TAGS" : [ "Skill Compass caching" ],
      "REQUIRES" : [ "rules", "cache_actions" ],
      "USES VARIABLES" : {
        "topic" : { "label" : "Topic", "type" : "node" },
        "account" : { "label" : "Account to clear cache for", "type" : "user" }
      },
      "RULES" : [
        { "RULE" : {
            "IF" : [ { "data_is_empty" : { "data" : [ "account" ] } } ],
            "DO" : [
              { "cache_actions_action_clear_cache_cid" : { "bin" : "cache", "cid" : "topic:[topic:nid]", "wildcard" : 1 } },
              { "cache_actions_action_clear_cache_cid" : { "bin" : "cache", "cid" : "topic:adm:[topic:nid]", "wildcard" : 1 } }
            ],
            "LABEL" : "Clear for all"
          }
        },
        { "RULE" : {
            "IF" : [ { "NOT data_is_empty" : { "data" : [ "account" ] } } ],
            "DO" : [
              { "cache_actions_action_clear_cache_cid" : {
                  "bin" : "cache",
                  "cid" : "topic:[topic:nid]:[account:uid]",
                  "wildcard" : 0
                }
              },
              { "cache_actions_action_clear_cache_cid" : {
                  "bin" : "cache",
                  "cid" : "topic:adm:[topic:nid]:[account:uid]",
                  "wildcard" : 0
                }
              }
            ],
            "LABEL" : "Clear for specific user"
          }
        }
      ]
    }
  }');
  $items['rules_sc_cache_topic_comment'] = entity_import('rules_config', '{ "rules_sc_cache_topic_comment" : {
      "LABEL" : "Skill Compass: Clear cache on topic comment",
      "PLUGIN" : "reaction rule",
      "TAGS" : [ "Skill Compass caching" ],
      "REQUIRES" : [ "rules", "comment" ],
      "ON" : [ "comment_presave" ],
      "IF" : [
        { "node_is_of_type" : {
            "node" : [ "comment:node" ],
            "type" : { "value" : { "sc_topic" : "sc_topic" } }
          }
        }
      ],
      "DO" : [
        { "component_rules_sc_cache_topic" : { "topic" : [ "comment:node" ], "account" : "0" } }
      ]
    }
  }');
  $items['rules_sc_cache_topic_relation'] = entity_import('rules_config', '{ "rules_sc_cache_topic_relation" : {
      "LABEL" : "Clear cache: topic relation page",
      "PLUGIN" : "rule set",
      "TAGS" : [ "Skill Compass caching" ],
      "REQUIRES" : [ "rules", "cache_actions" ],
      "USES VARIABLES" : {
        "topic" : { "label" : "Topic", "type" : "node" },
        "account" : { "label" : "Account to clear cache for", "type" : "user" }
      },
      "RULES" : [
        { "RULE" : {
            "IF" : [ { "data_is_empty" : { "data" : [ "account" ] } } ],
            "DO" : [
              { "cache_actions_action_clear_cache_cid" : { "bin" : "cache", "cid" : "topic_relations:[topic:nid]", "wildcard" : 1 } },
              { "cache_actions_action_clear_cache_cid" : {
                  "bin" : "cache",
                  "cid" : "topic_relations:adm:[topic:nid]",
                  "wildcard" : 1
                }
              }
            ],
            "LABEL" : "Clear for all"
          }
        },
        { "RULE" : {
            "IF" : [ { "NOT data_is_empty" : { "data" : [ "account" ] } } ],
            "DO" : [
              { "cache_actions_action_clear_cache_cid" : {
                  "bin" : "cache",
                  "cid" : "topic_relations:[topic:nid]:[account:uid]",
                  "wildcard" : 0
                }
              },
              { "cache_actions_action_clear_cache_cid" : {
                  "bin" : "cache",
                  "cid" : "topic_relations:adm:[topic:nid]:[account:uid]",
                  "wildcard" : 0
                }
              }
            ],
            "LABEL" : "Clear for specific user"
          }
        }
      ]
    }
  }');
  $items['rules_sc_cache_topic_relation_vote'] = entity_import('rules_config', '{ "rules_sc_cache_topic_relation_vote" : {
      "LABEL" : "Skill Compass: Clear cache on topic relation vote",
      "PLUGIN" : "reaction rule",
      "TAGS" : [ "Skill Compass caching" ],
      "REQUIRES" : [ "rules", "eck" ],
      "ON" : [ "sc_topicrelation_presave" ],
      "DO" : [
        { "component_rules_sc_cache_topic" : { "topic" : [ "sc-topicrelation:sid" ], "account" : "0" } },
        { "component_rules_sc_cache_topic" : { "topic" : [ "sc-topicrelation:tid" ], "account" : "0" } },
        { "component_rules_sc_cache_topic_relation" : { "topic" : [ "sc-topicrelation:sid" ], "account" : "0" } },
        { "component_rules_sc_cache_topic_relation" : { "topic" : [ "sc-topicrelation:tid" ], "account" : "0" } }
      ]
    }
  }');
  $items['rules_sc_cache_topic_save'] = entity_import('rules_config', '{ "rules_sc_cache_topic_save" : {
      "LABEL" : "Skill Compass: Clear cache on topic save",
      "PLUGIN" : "reaction rule",
      "TAGS" : [ "Skill Compass caching" ],
      "REQUIRES" : [ "rules" ],
      "ON" : [ "node_presave" ],
      "IF" : [
        { "node_is_of_type" : {
            "node" : [ "node" ],
            "type" : { "value" : { "sc_topic" : "sc_topic" } }
          }
        }
      ],
      "DO" : [
        { "component_rules_sc_cache_topic" : { "topic" : [ "node" ], "account" : "0" } },
        { "component_rules_sc_cache_topic_trees" : [] }
      ]
    }
  }');
  $items['rules_sc_cache_topic_trees'] = entity_import('rules_config', '{ "rules_sc_cache_topic_trees" : {
      "LABEL" : "Clear cache: topic tree pages",
      "PLUGIN" : "rule set",
      "TAGS" : [ "Skill Compass caching" ],
      "REQUIRES" : [ "cache_actions" ],
      "RULES" : [
        { "RULE" : {
            "DO" : [
              { "cache_actions_action_clear_cache_cid" : { "bin" : "cache", "cid" : "topic_tree_sub", "wildcard" : 1 } },
              { "cache_actions_action_clear_cache_cid" : { "bin" : "cache", "cid" : "topic_tree_req", "wildcard" : 1 } },
              { "cache_actions_action_clear_cache_cid" : { "bin" : "cache", "cid" : "topic_tree_search", "wildcard" : 1 } }
            ],
            "LABEL" : "Clear for all"
          }
        }
      ]
    }
  }');
  $items['rules_sc_example_caching'] = entity_import('rules_config', '{ "rules_sc_example_caching" : {
      "LABEL" : "Skill Compass: Clear cache on topic flags",
      "PLUGIN" : "reaction rule",
      "TAGS" : [ "Skill Compass caching" ],
      "REQUIRES" : [ "rules", "flag" ],
      "ON" : [ "flag_flagged_sc_proficiency", "flag_unflagged_sc_proficiency" ],
      "DO" : [
        { "component_rules_sc_cache_topic" : { "topic" : [ "flagged-node" ], "account" : [ "flagging-user" ] } },
        { "component_rules_sc_cache_topic_trees" : [] }
      ]
    }
  }');
  $items['rules_sc_resource_flag'] = entity_import('rules_config', '{ "rules_sc_resource_flag" : {
      "LABEL" : "Skill Compass: Clear cache on resource flag",
      "PLUGIN" : "reaction rule",
      "TAGS" : [ "Skill Compass caching" ],
      "REQUIRES" : [ "rules", "flag" ],
      "ON" : [
        "flag_flagged_sc_resource_completed",
        "flag_unflagged_sc_resource_completed",
        "flag_flagged_sc_resource_quicklist",
        "flag_unflagged_sc_resource_quicklist"
      ],
      "IF" : [
        { "entity_has_field" : { "entity" : [ "flagged-node" ], "field" : "sc_resource_topics" } }
      ],
      "DO" : [
        { "component_rules_sc_cache_resource" : { "resource" : [ "flagged-node" ], "account" : "0" } },
        { "LOOP" : {
            "USING" : { "list" : [ "flagged-node:sc-resource-topics" ] },
            "ITEM" : { "topic" : "Topic" },
            "DO" : [
              { "component_rules_sc_cache_topic" : { "topic" : [ "topic" ], "account" : "0" } }
            ]
          }
        },
        { "component_rules_sc_cache_resource_list" : [] },
        { "component_rules_clear_cache_resource_collections" : { "resource" : [ "flagged-node" ] } }
      ]
    }
  }');
  return $items;
}
