<?php

/**
 * Holds a hard-coded Rules action used to create a new resource collection more
 * easily.
 */

/**
 * Implements hook_rules_action_info(). 
 */
function sc_resource_collection_rules_action_info() {
  $actions = array(
    'sc_resource_collection_prepopulate' => array(
      'label' => t('Pre-populate new resource collection'),
      'group' => t('Skill Compass'),
      'access callback' => 'create sc_resource_collection content',
      'parameter' => array(
        'resources' => array(
          'type' => 'list<node>',
          'label' => t('Resources to include'),
        ),
      ),
    ),
  );
  return $actions;
}

/**
 * Redirects to a prepopulated page for adding resource collections.
 *
 * This function exists only as an attempt to work around the maximum nesting
 * level limit that might be triggered if doing this task in the standard Rules
 * way, and calling it from Views Bulk Operations. Also, it becomes a bit more
 * slick than creating the collection and *then* redirecting to its page.
 *
 * @param $resources
 *   A list of resources which the collection should contain.
 */
function sc_resource_collection_prepopulate($resources) {
  $resource_nids = implode(',', array_keys($resources));
  drupal_goto('node/add/sc-resource-collection', array(
    'query' => array('sc_resourcecollection_resources' => $resource_nids))
  );
}
